"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BintreeRangeSetTree = exports.BintreeRBRangeSetTree = void 0;
/**
 * These are adapter tree implementations from the `bintrees` package.
 * @packageDocumentation
 */
const bintrees_1 = require("bintrees");
/**
 * A red-black underlying tree for [[`RangeSet`]].
 */
class BintreeRBRangeSetTree {
    constructor(comparator) {
        this.tree = new bintrees_1.RBTree(comparator);
    }
    get size() {
        return this.tree.size;
    }
    insert(item) {
        this.tree.insert(item);
    }
    remove(item) {
        this.tree.remove(item);
    }
    clear() {
        this.tree.clear();
    }
    lowerBound(item) {
        return new BintreeIterator(this.tree.lowerBound(item));
    }
    upperBound(item) {
        return new BintreeIterator(this.tree.upperBound(item));
    }
    iterator() {
        return new BintreeIterator(this.tree.iterator());
    }
}
exports.BintreeRBRangeSetTree = BintreeRBRangeSetTree;
/**
 * A regular underlying binary search tree for [[`RangeSet`]].
 */
class BintreeRangeSetTree {
    constructor(comparator) {
        this.tree = new bintrees_1.BinTree(comparator);
    }
    get size() {
        return this.tree.size;
    }
    insert(item) {
        this.tree.insert(item);
    }
    remove(item) {
        this.tree.remove(item);
    }
    clear() {
        this.tree.clear();
    }
    lowerBound(item) {
        return new BintreeIterator(this.tree.lowerBound(item));
    }
    upperBound(item) {
        return new BintreeIterator(this.tree.upperBound(item));
    }
    iterator() {
        return new BintreeIterator(this.tree.iterator());
    }
}
exports.BintreeRangeSetTree = BintreeRangeSetTree;
/**
 * A universal `bintrees` iterator, compatible with both of the adapters.
 */
class BintreeIterator {
    constructor(orig) {
        this.orig = orig;
    }
    prev() {
        return this.orig.prev();
    }
    get data() {
        return this.orig.data();
    }
}
exports.BintreeRBRangeSetTree = BintreeRBRangeSetTree;
exports.BintreeRangeSetTree = BintreeRangeSetTree;
