"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumberSpec = exports.AbstractRangeSpec = void 0;
/**
 * A convenience wrapper around [[`RangeSpec`]].
 *
 * It allows most of the `RangeSpec` methods to be derived from a single `comparator`.
 */
class AbstractRangeSpec {
    isEqual(a, b) {
        return this.comparator(a, b) === 0;
    }
    isGreaterThan(value, than) {
        return this.comparator(value, than) > 0;
    }
    isGreaterOrEqualTo(value, thanTo) {
        return this.comparator(value, thanTo) >= 0;
    }
    isLessOrEqualTo(value, thanTo) {
        return this.comparator(value, thanTo) <= 0;
    }
    isLessThan(value, than) {
        return this.comparator(value, than) < 0;
    }
}
exports.AbstractRangeSpec = AbstractRangeSpec;
/**
 * A convenience spec for JS `number`.
 *
 * [[`Range`]] constructors use it by default when no explicit spec was provided.
 */
class NumberSpec extends AbstractRangeSpec {
    get comparator() {
        return (a, b) => {
            if (a === b)
                return 0; // Infinity case should return 0 here
            return a - b;
        };
    }
    isInfinity(value) {
        return +value === Infinity || -value === Infinity;
    }
}
exports.NumberSpec = NumberSpec;
